$set 14 #main

$ #RCRequiresArg
# : '-rc'  \n
$ #DISPLAYRequiresArg
# : '-display'  \n
$ #WarnDisplaySet
# :        'DISPLAY'\n
$ #Usage
# Fluxkbox %s: (c) %s Henrik Kinnunen\n\n\
  -display <string>\t\tuse display connection.\n\
  -rc <string>\t\t\t   .\n\
  -version\t\t\t   .\n\
  -info\t\t\t\tdisplay some useful information.\n\
  -log <filename>\t\t\tlog output to file.\n\
  -help\t\t\t\t     .\n\n
$ #CompileOptions
#      :\n\
  Debugging\t\t\t%s\n\
  Interlacing:\t\t\t%s\n\
  Shape:\t\t\t%s\n\
  Slit:\t\t\t\t%s\n\
  8bpp Ordered Dithering:\t%s\n\n
